import pytest
from ....src.data_pipeline.feature_engineering.key_smash import KeySmash


@pytest.mark.parametrize("text, expected", [
    ("PUENTECILLA KM. 1.7", 1.121212121212121),
    ("ASDASD XXXX", 3.0)
])
def test_calculate_char_frequency_metric(text, expected):
    key_smash = KeySmash()
    assert key_smash.calculate_char_frequency_metric(text) == expected


@pytest.mark.parametrize("text, opt, expected", [
    ("PUENTECILLA KM. 1.7", "vowels", 0.21052631578947367),
    ("ASDASD XXXX", "consonants", 2.1818181818181817),
    ("!@#$% ASDFGHJKL", "special_characters", 1.6666666666666667)
])
def test_calculate_irregular_sequence_metric(text, opt, expected):
    key_smash = KeySmash()
    assert key_smash.calculate_irregular_sequence_metric(text, opt) == expected


@pytest.mark.parametrize("text, expected", [
    ("ABC 123 !@#", 0.0),
    ("ABC123 !@#", 0.9)
])
def test_calculate_number_count_metric(text, expected):
    key_smash = KeySmash()
    assert key_smash.calculate_number_count_metric(text) == expected



import pytest
from ...src.parser.parser_base import ParserBase


@pytest.fixture
def parser():
    return ParserBase()


@pytest.mark.parametrize("variable, field, expected_output", [
    ({'field1': 'value1'}, 'field1', 'value1'),
    ({'field1': 'value1'}, 'field2', ValueError),
    ({'field1': 'value1'}, 'value2', ValueError)
])
def test_try_get(parser, variable, field, expected_output):
    if expected_output == KeyError:
        with pytest.raises(KeyError):
            parser._try_get(variable, field)
    elif expected_output == ValueError:
        with pytest.raises(ValueError):
            parser._try_get(variable, field)
    else:
        assert parser._try_get(variable, field) == expected_output


@pytest.mark.parametrize("variable, field, default_value, expected_output", [
    ({'field1': 'value1'}, 'field1', 'default', 'value1'),
    ({'field1': 'value1'}, 'field2', 'default', 'default')
])
def test_get(parser, variable, field, default_value, expected_output):
    assert parser._get(variable, field, default_value) == expected_output



import pytest
from ...src.parser.feature_engineering_parser import (
    FeatureEngineeringParser,
)


class TestFeatureEngineeringParser:
    @pytest.mark.parametrize(
        "test_input, expected_output",
        [
            # Test case 1 - empty input
            ([], None),
            # Test case 2 - no columns in input
            ([{"input": {"features": {"word_embedding": "es"}}}], ValueError),
            # Test case 3 - no features in input
            ([{"input": {"columns": [{"col1": "string"}]}}], ValueError),
            # Test case 4 - columns with alias not present in feature
            (
                (
                    [
                        {
                            "input": {
                                "columns": [{"col1": "string"}],
                                "features": {
                                    "word_embedding": {"col1": {"dimensions": 30}}
                                },
                            }
                        }
                    ]
                ),
                (
                    [
                        {
                            "columns_alias": ["col1"],
                            "columns_set": [{"col1": "string"}],
                            "data_lang": "es",
                            "dimensions": {"col1": 30},
                            "enabled_features": {
                                "ksmash_sequence_vowels": True,
                                "ksmash_sequence_consonants": True,
                                "ksmash_sequence_special_characters": True,
                                "ksmash_numbers": True,
                                "ksmash_char_frequence": True,
                                "word_embedding": True,
                            },
                        }
                    ],
                    ["col1"],
                ),
            ),
            # Test case 5 - valid input
            (
                (
                    [
                        {
                            "input": {
                                "columns": [{"col1": "string"}],
                                "features": {
                                    "word_embedding": {"col1": {"dimensions": 30}}
                                },
                            }
                        }
                    ]
                ),
                (
                    [
                        {
                            "columns_alias": ["col1"],
                            "columns_set": [{"col1": "string"}],
                            "data_lang": "es",
                            "dimensions": {"col1": 30},
                            "enabled_features": {
                                "ksmash_sequence_vowels": True,
                                "ksmash_sequence_consonants": True,
                                "ksmash_sequence_special_characters": True,
                                "ksmash_numbers": True,
                                "ksmash_char_frequence": True,
                                "word_embedding": True,
                            },
                        }
                    ],
                    ["col1"],
                ),
            ),
            # Test case 6 - input with multiple features
        ],
    )
    def test_parser(self, test_input, expected_output):
        parser = FeatureEngineeringParser()

        if [
            {
                "input": {
                    "columns": [{"col1": "string"}],
                    "features": {"word_embedding": {"col1": {"dimensions": 30}}},
                }
            }
        ] == test_input:
            print("OOOASDAS")
            print(parser.parse(test_input))
            print("OOOASDAS")

        try:
            assert parser.parse(test_input) == expected_output

        except ValueError or AssertionError as e:
            assert isinstance(e, expected_output)



import pytest
from ...src.parser.model_parser import ModelParser


@pytest.mark.parametrize(
    "data, expected_output",
    [
        (
            {
                "random_forest": [
                    {
                        "input": {
                            "type": "ADDRESS",
                            "columns": ["col1", "col2"],
                            "thresholds": {"test_size": 0.2, "n_estimators": 50},
                        }
                    }
                ]
            },
            [],
        ),
        (
            {
                "random_forest": [
                    {
                        "input": {
                            "type": "ADDRESS",
                            "columns": ["col1", "col2"],
                            "thresholds": {
                                "test_size": 0.2,
                                "n_estimators": 50,
                                "keyboard_smash": {"col1": 1.00, "col2": 2.2499},
                            },
                        }
                    }
                ]
            },
            [],
        ),
    ],
)
def test_parse(data, expected_output):
    columns_alias = ["col1", "col2"]
    parser = ModelParser(columns_alias)
    assert parser.parse(data) == expected_output




import pandas as pd
import pytest
from ....src.data_pipeline.pre_processing.concatenate_columns import get_concatenated_column
# Test cases that should pass
passing_test_cases = [
    {'csv': pd.DataFrame({'col1': [1, 2, 3], 'col2': [4, 5, 6]}), 'columns': 'col1', 'column_name': 'new_col',
     'expected': pd.DataFrame({'new_col': [1, 2, 3]})},
    {'csv': pd.DataFrame({'col1': [1, 2, 3], 'col2': [4, 5, 6], 'col3': [7, 8, 9]}), 'columns': ['col1', 'col2'],
     'column_name': 'new_col', 'expected': pd.DataFrame({'new_col': ['1 4', '2 5', '3 6']})},
]

# Test cases that should fail
failing_test_cases = [
    {'csv': pd.DataFrame({'col1': [1, 2, 3], 'col2': [4, 5, 6]}), 'columns': ['col1', 'col3'], 'column_name': 'new_col',
     'expected': KeyError},
]


@pytest.mark.parametrize("test_case", passing_test_cases)
def test_get_concatenated_column_passes(test_case):
    csv = test_case['csv']
    columns = test_case['columns']
    column_name = test_case['column_name']
    expected = test_case['expected']

    result = get_concatenated_column(csv, columns, column_name)
    assert result.equals(expected)


@pytest.mark.parametrize("test_case", failing_test_cases)
def test_get_concatenated_column_fails(test_case):
    csv = test_case['csv']
    columns = test_case['columns']
    column_name = test_case['column_name']
    expected = test_case['expected']

    with pytest.raises(expected):
        get_concatenated_column(csv, columns, column_name)



import pytest
from ...src.parser.YAML_parser import YAMLParser

# Test data
valid_yaml = """
dag:
  id: my_dag
  data_path: /path/to/data
  output_folder: /path/to/output
  description: My DAG
  feature_engineering: feature_engineering.py
  model: my_model.py
"""

invalid_yaml = """
dag:
  data_path: /path/to/data
  output_folder: /path/to/output
  description: My DAG
  feature_engineering: feature_engineering.py
  model: my_model.py
"""

expected_output = {
    "dag_id": "my_dag",
    "data_path": "/path/to/data",
    "output_folder": "/path/to/output",
    "description": "My DAG",
    "feature_engineering": "feature_engineering.py",
    "model": "my_model.py",
}


# Fixtures
@pytest.fixture
def valid_yaml_parser():
    with open("valid_config.yaml", "w") as f:
        f.write(valid_yaml)
    return YAMLParser("valid_config.yaml")


@pytest.fixture
def invalid_yaml_parser():
    with open("invalid_config.yaml", "w") as f:
        f.write(invalid_yaml)
    return YAMLParser("invalid_config.yaml")


# Tests
def test_valid_yaml(valid_yaml_parser):
    assert valid_yaml_parser.parse() == expected_output


def test_invalid_yaml(invalid_yaml_parser):
    with pytest.raises(ValueError, match=r".*Error in file invalid_config.yaml: the field `id` is required.*"):
        invalid_yaml_parser.parse()



import pytest
from whatlies.language import BytePairLanguage
import numpy as np
from ....src.data_pipeline.feature_engineering.word_embedding import WordEmbedding


@pytest.mark.parametrize("lang, dimensions", [
    ("en", 25),
    ("es", 50),
    ("fr", 100)
])
def test_word_embedding_init(lang, dimensions):
    we = WordEmbedding(lang, dimensions)
    assert isinstance(we.bpl, BytePairLanguage)
    assert we.bpl.lang == lang
    assert we.bpl.dim == dimensions


@pytest.mark.parametrize("text, expected_shape", [
    ("This is a text", (50,)),
    ("Este es un texto", (50,)),
    ("C'est un texte", (50,)),
    ("&^%$#@", (50,))
])
def test_word_embedding_get_embedding(text, expected_shape):
    we = WordEmbedding("en", 50)
    embedding = we.get_embedding(text)
    assert isinstance(embedding, np.ndarray)
    assert embedding.shape == expected_shape
